@@ -5,7 +5,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Time::Piece;
 use CLDR::Number;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub register {
     my ($self, $app, $config) = @_;
@@ -44,6 +44,16 @@ sub register {
         my $formatted = $objects{cur}->{$locale}->format( $number );
         return $formatted;
     } );
+
+    $app->helper( decimal => sub {
+        my ($c, $number, $locale) = @_;
+
+        $objects{cldr}->{$locale} ||= CLDR::Number->new( locale => $locale );
+        $objects{dec}->{$locale}  ||= $objects{cldr}->{$locale}->decimal_formatter;
+
+        my $formatted = $objects{dec}->{$locale}->format( $number );
+        return $formatted;
+    } );
 }
 
 sub _translate {
@@ -183,7 +193,7 @@ Mojolicious::Plugin::I18NUtils - provide some helper functions for I18N
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
